import { Metadata, Loader } from '@zeedhi/core';
import {
  Modal,
  ModalService,
  Form,
} from '@zeedhi/common';
import BudgetParameters from '@/controllers/BudgetParameters';
import ChangeLabel from '@/helper/Labels';
import { ZdTabs } from '@zeedhi/vuetify';
// import { TekGrid } from '@zeedhi/teknisa-components-common';

export class FilterOperatingBudgetModalController {
  private filterOperatingBudgetModal!: Modal;
  
  public periodSize = 10;
  
  public filter;
  
  public clean = false;
  
  periodList = [
    {
      NRPERIODOORCA: 1,
      DSPERIODOORCA: '1° Semestre',
      IDPERIODOORCA: 'SEMESTRAL',
    },
    {
      NRPERIODOORCA: 2,
      DSPERIODOORCA: '2° Semestre',
      IDPERIODOORCA: 'SEMESTRAL',
    },
    {
      NRPERIODOORCA: 1,
      DSPERIODOORCA: '1° Quadrimestre',
      IDPERIODOORCA: 'QUADRIMESTRAL',
    },
    {
      NRPERIODOORCA: 2,
      DSPERIODOORCA: '2° Quadrimestre',
      IDPERIODOORCA: 'QUADRIMESTRAL',
    },
    {
      NRPERIODOORCA: 3,
      DSPERIODOORCA: '3° Quadrimestre',
      IDPERIODOORCA: 'QUADRIMESTRAL',
    },
    {
      NRPERIODOORCA: 1,
      DSPERIODOORCA: '1° Trimestre',
      IDPERIODOORCA: 'TRIMESTRAL',
    },
    {
      NRPERIODOORCA: 2,
      DSPERIODOORCA: '2° Trimestre',
      IDPERIODOORCA: 'TRIMESTRAL',
    },
    {
      NRPERIODOORCA: 3,
      DSPERIODOORCA: '3° Trimestre',
      IDPERIODOORCA: 'TRIMESTRAL',
    },
    {
      NRPERIODOORCA: 4,
      DSPERIODOORCA: '4° Trimestre',
      IDPERIODOORCA: 'TRIMESTRAL',
    },
    {
      NRPERIODOORCA: 1,
      DSPERIODOORCA: '1° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 2,
      DSPERIODOORCA: '2° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 3,
      DSPERIODOORCA: '3° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 4,
      DSPERIODOORCA: '4° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 5,
      DSPERIODOORCA: '5° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 6,
      DSPERIODOORCA: '6° Bimestre',
      IDPERIODOORCA: 'BIMESTRAL',
    },
    {
      NRPERIODOORCA: 1,
      DSPERIODOORCA: 'Janeiro',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 2,
      DSPERIODOORCA: 'Fevereiro',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 3,
      DSPERIODOORCA: 'Março',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 4,
      DSPERIODOORCA: 'Abril',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 5,
      DSPERIODOORCA: 'Maio',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 6,
      DSPERIODOORCA: 'Junho',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 7,
      DSPERIODOORCA: 'Julho',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 8,
      DSPERIODOORCA: 'Agosto',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 9,
      DSPERIODOORCA: 'Setembro',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 10,
      DSPERIODOORCA: 'Outubro',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 11,
      DSPERIODOORCA: 'Novembro',
      IDPERIODOORCA: 'MENSAL',
    },
    {
      NRPERIODOORCA: 12,
      DSPERIODOORCA: 'Dezembro',
      IDPERIODOORCA: 'MENSAL',
    },
  ];
  
  public async createfilterOperatingBudgetModal() {
    this.filterOperatingBudgetModal = await ModalService.createFromJson('/modals/filterOperatingBudgetModal', true);
    this.filterOperatingBudgetModal.show();
  }
  
  public destroyfilterOperatingBudgetModal() {
    this.filterOperatingBudgetModal?.destroy();
  }
  
  public openfilterOperatingBudgetModal() {
    this.filterOperatingBudgetModal.show();
  }
  
  public closefilterOperatingBudgetModal() {
    this.filterOperatingBudgetModal.hide();
    this.clearInputsFilter();
  }
  
  dataPeriod(IDPERIODOORCA: string): any {
    const period = this.periodList.filter((item) => item.IDPERIODOORCA === IDPERIODOORCA);
    // const periodTranslate = period.forEach((item) => {
    //   item.DSPERIODOORCA = I18n.translate(item.DSPERIODOORCA);
    // });
    return period;
  }
  
  budgetPeriod({ component }) {
    const period = BudgetParameters.getParameters.IDPERIODOORCA;
    const textPeriod = ChangeLabel.getLabel('P_'.concat(period));
    
    if (component.name === 'IDPERIODOORCA') {
      component.value = textPeriod;
      
      if (period === 'ANUAL') {
        this.periodSize = 10;
      } else {
        this.periodSize = 4;
      }
    } else if (period === 'ANUAL') {
      component.isVisible = false;
      component.validations.required = false;
      component.datasource.data = [];
    } else {
      component.datasource.data = this.dataPeriod(period);
    }
  }
  
  public clearInputsFilter() {
    const form = Metadata.getInstance<Form>('formFilterOperatingBudget');
    const idPeriod = form.value.IDPERIODOORCA;
    form.clearForm();
    form.value.IDPERIODOORCA = idPeriod;
  }
  
  public async applyFilter() {
    const period = BudgetParameters.getParameters.IDPERIODOORCA;
    const filter = Metadata.getInstance<Form>('formFilterOperatingBudget');
    
    if ((filter.value.NRANOORCAGOP && filter.value.NRPERIODOORCA) || (filter.value.NRANOORCAGOP && period === 'ANUAL')) {
      const operatingBudgetModal = Loader.getInstance('CalculationOperatingBudgetController');

      BudgetParameters.definesMonths(filter.value.NRPERIODOORCA ? filter.value.NRPERIODOORCA.NRPERIODOORCA : 1);
      operatingBudgetModal.filter = filter.value;
      operatingBudgetModal.filterData = BudgetParameters.treatParameters(filter.value);
      if (!this.clean) {
        this.clean = true;
      } else {
        this.clearData();
      }
      operatingBudgetModal.defineTitleBudget();
      
      this.filterOperatingBudgetModal.hide();
    } else {
      filter.validate();
    }
  }
  
  public clearData() {
    const tabsBudget = Metadata.getInstance<ZdTabs>('tabsBudget');
    BudgetParameters.setNotRecharged();
    tabsBudget.activeTab = tabsBudget.tabs.findIndex((obj) => (obj.isVisible === true));
  }
}
